<?php

namespace Drupal\media_pdf_thumbnail\Form;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\Messenger;
use Drupal\media_pdf_thumbnail\Manager\MediaPdfThumbnailQueueManager;
use Drupal\media_pdf_thumbnail\Service\MediaPdfThumbnailService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class ThumbnailGenerationSettingsForm
 *
 * @package Drupal\media_pdf_thumbnail\Form
 */
class ThumbnailGenerationSettingsForm extends FormBase {

  /**
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * @var \Drupal\Core\Messenger\Messenger
   */
  protected $messenger;

  /**
   * @var \Drupal\Core\Config\ConfigFactory
   */
  protected $configFactory;

  /**
   * @var \Drupal\media_pdf_thumbnail\Manager\MediaPdfThumbnailQueueManager
   */
  protected $mediaPdfThumbnailQueueManager;

  /**
   * @var \Drupal\media_pdf_thumbnail\Service\MediaPdfThumbnailService
   */
  protected $mediaPdfThumbnailService;

  /**
   * ThumbnailGenerationSettingsForm constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   * @param \Drupal\Core\Messenger\Messenger $messenger
   * @param \Drupal\Core\Config\ConfigFactory $configFactory
   * @param \Drupal\media_pdf_thumbnail\Manager\MediaPdfThumbnailQueueManager $mediaPdfThumbnailQueueManager
   * @param \Drupal\media_pdf_thumbnail\Service\MediaPdfThumbnailService $mediaPdfThumbnailService
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager, Messenger $messenger, ConfigFactory $configFactory, MediaPdfThumbnailQueueManager $mediaPdfThumbnailQueueManager, MediaPdfThumbnailService $mediaPdfThumbnailService) {
    $this->entityTypeManager = $entityTypeManager;
    $this->messenger = $messenger;
    $this->configFactory = $configFactory;
    $this->mediaPdfThumbnailQueueManager = $mediaPdfThumbnailQueueManager;
    $this->mediaPdfThumbnailService = $mediaPdfThumbnailService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('entity_type.manager'), $container->get('messenger'), $container->get('config.factory'), $container->get('media_pdf_thumbnail.queue.manager'), $container->get('media_pdf_thumbnail.service'));
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'thumbnail_generation_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['help'] = [
      '#type' => 'markup',
      '#markup' => $this->t('Submitting this form will process the Queue which contains @number items.', ['@number' => $this->mediaPdfThumbnailQueueManager->numberOfItems()]),
    ];

    $form['regenerate_all'] = [
      '#type' => 'checkbox',
      '#title' => 'Enforce regenerating thumbnails for all Media entities.',
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Regenerate thumbnails'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    if ($form_state->getValue('regenerate_all')) {
      $this->mediaPdfThumbnailService->regenerateAllThumbnails();
    }
    else {
      $this->mediaPdfThumbnailQueueManager->executeQueue();
    }
  }

}
